@@ -18,13 +18,14 @@
   *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   */
 
+#define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
 #include <unistd.h>
 
-#define VERSION "1.2.0"
+#define VERSION "1.2.2"
 #define USAGE "Usage: bchunk [-v] [-r] [-p (PSX)] [-w (wav)] [-s (swabaudio)]\n" \
         "         <image.bin> <image.cue> <basename>\n" \
 	"Example: bchunk foo.bin foo.cue foo\n" \
@@ -271,11 +272,10 @@ int writetrack(FILE *bf, struct track_t *track, char *bname)
 	int16_t i;
 	float fl;
 	
-	if (!(fname = malloc(strlen(bname) + 8))) {
-		fprintf(stderr, "main(): malloc() failed, out of memory\n");
+	if (asprintf(&fname, "%s%2.2d.%s", bname, track->num, track->extension) == -1) {
+		fprintf(stderr, "writetrack(): asprintf() failed, out of memory\n");
 		exit(4);
 	}
-	sprintf(fname, "%s%2.2d.%s", bname, track->num, track->extension);
 	
 	printf("%2d: %s ", track->num, fname);
 	
@@ -387,7 +387,6 @@ int main(int argc, char **argv)
 {
 	char s[CUELLEN+1];
 	char *p, *t;
-	int i, idx;
 	struct track_t *tracks = NULL;
 	struct track_t *track = NULL;
 	struct track_t *prevtrack = NULL;
@@ -417,7 +416,6 @@ int main(int argc, char **argv)
 		return 3;
 	}
 	
-	i = 0;
 	while (fgets(s, CUELLEN, cuef)) {
 		while ((p = strchr(s, '\r')) || (p = strchr(s, '\n')))
 			*p = '\0';
@@ -426,12 +424,12 @@ int main(int argc, char **argv)
 			printf("\nTrack ");
 			if (!(p = strchr(p, ' '))) {
 				fprintf(stderr, "... ouch, no space after TRACK.\n");
-				continue;
+				exit(3);
 			}
 			p++;
 			if (!(t = strchr(p, ' '))) {
 				fprintf(stderr, "... ouch, no space after track number.\n");
-				continue;
+				exit(3);
 			}
 			*t = '\0';
 			
@@ -460,23 +458,22 @@ int main(int argc, char **argv)
 		} else if ((p = strstr(s, "INDEX"))) {
 			if (!(p = strchr(p, ' '))) {
 				printf("... ouch, no space after INDEX.\n");
-				continue;
+				exit(3);
 			}
 			p++;
 			if (!(t = strchr(p, ' '))) {
 				printf("... ouch, no space after index number.\n");
-				continue;
+				exit(3);
 			}
 			*t = '\0';
 			t++;
-			idx = atoi(p);
 			printf(" %s %s", p, t);
 			track->startsect = time2frames(t);
 			track->start = track->startsect * SECTLEN;
 			if (verbose)
 				printf(" (startsect %ld ofs %ld)", track->startsect, track->start);
 			if ((prevtrack) && (prevtrack->stopsect < 0)) {
-				prevtrack->stopsect = track->startsect;
+				prevtrack->stopsect = track->startsect - 1;
 				prevtrack->stop = track->start - 1;
 			}
 		}
@@ -484,7 +481,7 @@ int main(int argc, char **argv)
 	
 	if (track) {
 		fseek(binf, 0, SEEK_END);
-		track->stop = ftell(binf);
+		track->stop = ftell(binf) - 1;
 		track->stopsect = track->stop / SECTLEN;
 	}
 	
